import { Component } from "../component";
import { ContextMemberFactory } from "../context";
import "../prelude";
import { App } from "./app";
import { AppHookMap } from "./hooks";
export interface Plugin extends Partial<AppHookMap> {
    name?: string;
    components?: Record<string, new () => Component>;
    contextFuncs?: Record<string, ContextMemberFactory>;
    htmlElementAlias?: Record<string, string>;
    onInstall?(app: App): void;
}
type PluginItem = Plugin | false | null | undefined | readonly PluginItem[] | Promise<Plugin | false | null | undefined | readonly PluginItem[]>;
export type PluginOption = PluginItem[];
export declare function installPlugins(app: App, plugins: PluginOption): Promise<void>;
export interface Plugins {
}
type ExtractFuncName<N> = N extends string ? N extends `$${string}` ? never : N : never;
type GetContextFuncs<T extends Plugin> = T extends any ? {
    [K in ExtractFuncName<keyof T["components"]>]: T["components"][K] extends new () => {
        $main: infer F;
    } ? F : never;
} & {
    [K in ExtractFuncName<keyof T["contextFuncs"]>]: T["contextFuncs"][K] extends ContextMemberFactory<infer F> ? F : never;
} : never;
type GetComponents<T extends Plugin> = T extends any ? {
    [K in ExtractFuncName<keyof T["components"]>]: T["components"][K] extends new () => infer C ? C : never;
} : never;
type UnionToIntersection<T> = (T extends any ? (x: T) => any : never) extends (x: infer R) => any ? R : never;
type NormalizePlugins<T> = T extends (...args: any[]) => infer R ? NormalizePlugins<R> : T extends readonly any[] ? T[number] extends infer R ? NormalizePlugins<R> : never : T extends Promise<infer R> ? NormalizePlugins<R> : T extends Plugin ? T : never;
type PluginContextFuncs = UnionToIntersection<GetContextFuncs<NormalizePlugins<Plugins[keyof Plugins]>>>;
type PluginComponents = UnionToIntersection<GetComponents<NormalizePlugins<Plugins[keyof Plugins]>>>;
declare module ".." {
    interface ContextFuncs extends PluginContextFuncs {
    }
    interface Components extends PluginComponents {
    }
}
export {};
//# sourceMappingURL=plugin.d.ts.map