import { Component } from "./component";
/**
 * The base class of all trigger components.
 *
 * A trigger component is a component that can fire events with data.
 * The return value of the context function is whether the event is fired.
 */
export declare abstract class TriggerComponent<Ev = unknown> extends Component {
    private $_fired;
    private $_firedData;
    /**
     * Fire an event with data.
     *
     * @param data The data of the event.
     */
    protected readonly $fire: (data: Ev) => void;
    /**
     * Create a function that fires an event with data.
     *
     * @param data The data of the event.
     * @returns A function that fires the event.
     */
    protected readonly $fireWith: (data: Ev) => () => void;
    protected get $fired(): boolean;
}
//# sourceMappingURL=trigger.d.ts.map